" File: VBlockquote.vim
"
" Purpose: Insert (Quote) stuff the way some emacs people do
" Example:
" ,----[ title ]
" | Inspired by Blockquote.vim
" | by Tilmann Bitterberg <tilmann@bitterberg.de>
" | ...
" `----
"
" Use: visually select text and
"	:call VBlockquote()
"	or if you want to create a title
"	:call VBlockquote("title")
"
" Author: Ralf Arens <ralf.arens@gmx.net>
" Last modified: Thursday, 23 November 2000 - 14:59
" + changed section "remove trailing whitespace", no more trouble with
" + trailing whitespace.


function! VBlockquote(...) range
    " put `| ' at beginning of line
    exe a:firstline.",".a:lastline."s/^/| /"
    " remove trailing whitespaces
    exe a:firstline.",".a:lastline.'s/^| $/|/e'
    " generate tail
    exe a:lastline."put ='`----------------------------------------------------------------------'"
    " set mark
    normal m'
    " generate title
    if ( a:0 != 0 && a:1 != "" )
        " -> extra argument a:1
        let @z = " [ ".a:1." ] "
        let len_count = ( 70 - strlen(@z) ) / 2
        if ( ( strlen(@a) % 2 ) != 0 )
            let @z = @z."-"
        endif
        while len_count > 0
            let len_count = len_count - 1
            let @z = "-".@z."-"
        endwhile
        let @z = ",".@z
    else
        let @z = ",----------------------------------------------------------------------"
    endif
    exe a:firstline."put! z"
    " jump back to mark
    normal ''
endfunction

