"-----------------------------------------------------------------------------
"
" Filename:      functions.vim
" Author:        Helmut Kolb - koh
"
" Last modified: Wednesday, 05 January 2005 - 10:36
"
" History:       Creation on Friday, 17 November 2000 - 12:49
"
"-----------------------------------------------------------------------------

" ein tag um den bereich legen
function Tag(tag)
  execute "normal a<".a:tag.">\<C-R>\"</".a:tag.">\<Esc>"
endfunction

" mail/news besonderheiten
function FT_mail()
  set tw=72
endfunction

" c, cpp, C, h, H besonderheiten
function FT_c()
  " keyboardmappings zuordnen
  call SourceMappings()
  " einrueckungen
  set autoindent
  " schaut schoener aus...
  set tw=80
  set ts=2
  " todo tag und "#" sachen
  syn keyword cTodo  COMBAK
  syn match   cTodo  "^[- ]*COMBAK[- ]*$"
  syn match   cTodo  "@@@@@"
  set isk+=#
  " kommentar
  set comments=sr:/*,mb:*,elx:*/,://
endfunction

" php sourcefiles
function FT_php()
  " keyboardmappings zuordnen
  call PHPMappings()
  " einrueckungen
  set autoindent
  " schaut schoener aus...
  set tw=80
endfunction

" tex/latex sourcefiles
function FT_tex()
  " einrueckungen
  set autoindent
  " schaut schoener aus...
  set tw=80
endfunction

" daten in neue files schreiben
function NewTemplateFile(filename)
  if line("$") > 20
    let last = 20
  else
    let last = line("$")
  endif
  execute "1," . last . "g/Last modified:/s/Last modified:.*/Last modified: " . strftime("%A, %d %B %Y - %H:%M")
  execute "1," . last . "g/History:/s/History:.*/History:       Creation on " . strftime("%A, %d %B %Y - %H:%M")
  execute "1," . last . "g/Filename:/s/Filename:.*/Filename:      " . a:filename
endfunction

" zwischen (c-)source und header files umschalten
function ToggleSourceHeader(command)
  let extension = expand("%:e")
  let root = expand("%:t:r")
  if extension == "c" || extension == "cpp" || extension == "C"
    execute a:command root . ".h"
  elseif extension == "h" || extension == "H"
    if filereadable( root.".cpp" )
      execute a:command root . ".cpp"
    else
      execute a:command root . ".c"
    endif
  endif
endfunction

" mitspeichern eines datums im file, sofern schon vorhanden
function UpdateModDate()
  if line("$") > 20
    let last = 20
  else
    let last = line("$")
  endif
  execute "1," . last . "g/Last modified:/s/Last modified:.*/Last modified: " . strftime("%A, %d %B %Y - %H:%M")
endfunction

" dezimal auf hex umrechnen
function Dec2Hex(nummer)
   let num = a:nummer
   let ret = ""
   while num
     let ret = '0123456789ABCDEF'[num % 16] . ret
     let num = num / 16
   endwhile
   return ret
endfunction

" eine hex ziffer in dezimal umrechnen
function HexDigitToDec(digit)
   let char = a:digit
   if (char == "a") || (char == "A")
      let value = 10
   elseif (char == "b") || (char == "B")
      let value = 11
   elseif (char == "c") || (char == "C")
      let value = 12
   elseif (char == "d") || (char == "D")
      let value = 13
   elseif (char == "e") || (char == "E")
      let value = 14
   elseif (char == "f") || (char == "F")
      let value = 15
   else
      let value = char
   endif
   return value
endfunction

" eine hex zahl in dezimal umrechnen
function Hex2Dec(nummer)
   let ret = 0
   let len = strlen(a:nummer)
   let pos = 0
   while pos < len 
     let value = HexDigitToDec(a:nummer[pos])
     let ret = (ret * 16) + value
     let pos = pos + 1
   endwhile
   return ret
endfunc

" grep mit der letzten visuellen selektion
function MyGrep(options,expression,files)
  execute ":grep ".a:options." ".a:expression." ".a:files
endfunction

" -=> hex/dec kommandos
command -nargs=1 Hex2Dec echo Hex2Dec(<f-args>)
command -nargs=1 Dec2Hex echo Dec2Hex(<args>)

" ein schoenes beispiel:
"
":echo getline(".")
":echo substitute(getline("."), '\d\+', "(&+1)", "g")
":echo "'".substitute(getline("."), '\d\+', "'.(&+1).'", "g")."'"
":execute "echo '".substitute(getline("."), '\d\+', "'.(&+1).'", "g")."'"
"
function VersionInc()
  execute "let newline = '".substitute(getline("."), '\d\+', "'.(&+1).'","g")."'"
  call setline(line("."), newline)
endfunction

" korrigiert falsch geschriebene worte
function SpellCheck(word)
endfunction

" faltet c-sourcecode anhand der "{" / "}"
function FoldSource()
  " keine 6er, damit gibt es keinen fold...
  if version==507
    return
  endif
  normal gg
  while search("^{", 0) == 0
    normal zf%
  endwhile
  normal gg
  " und alles wieder entklappen
  normal zR
  " an die letztgueltige position zurueckspringen
  normal '"
endfunction

" versionsstring zurueckgeben
function Version()
  return version
endfunction

" die eingeschaltenen options ruecksetzen
function Options()
"  let opt="VIM-".Version().": "
  " fileformat
"  let opt=opt." ".&fileformat." "
  let opt=&fileformat
  " autoindent
  if &ai
    let opt=opt." i"
  else
    let opt=opt." !i"
  endif
  " expandtab
  if &et
    let opt=opt." t"
  else
    let opt=opt." !t"
  endif
  " hlsearch
  if &hls
    let opt=opt." s"
  else
    let opt=opt." !s"
  endif
  " paste
  if &paste
    let opt=opt." p"
  else
    let opt=opt." !p"
  endif
  " shiftwidth
  let opt=opt." (".&shiftwidth
  " textwidth
  let opt=opt."/".&tw
  " tabstop
  let opt=opt."/".&ts.")"
  " lines and columns
"  let opt=opt." \[".&lines.",".&columns."\]"
  return opt
endf

" -=> HilfeSuchFunktion (Commando)
command! -nargs=1 -complete=help Help  grep <args> $VIMRUNTIME/doc/*.txt

fun! CVSCommitFile()
  let msg = input("Log message?")
  :update 
"  :!cvs commit -m "'" . msg . "' " . expand("%")
  "normal ":!cvs commit -m \"'\" . msg . \"' \" . expand(\"%\")"
  exec "!cvs commit -m '" . msg . "' " . expand("%")
  "exec "!cvs commit -m '" . msg . "' %"
  :edit
endfun

